pub struct System<R, Q, F> { /* private fields */ }Expand description
The concrete type which contains the system closure provided by the user. This struct should
not be constructed directly, and instead should be created using SystemBuilder.
Implements Schedulable which is consumable by the StageExecutor, executing the closure.
Also handles caching of archetype information, as well as maintaining the provided information about what queries this system will run and, as a result, its data access.